<form id="group-form">
	<div class="inside-wrapper">
        <div class="show-help"><a class="show-configuration-help" target="_blank" href="/users/admin/help/group.html">Help</a></div>
		<table class="normalrightcolumn">
			<tr>
				<th><label for="name">Name</label></th>
				<td><input type="text" id="name" name="name" value="<%-values.id ? values.id : ''%>" /></td>
			</tr>
		</table>
	</div>
	<table class="buttons">
		<tr>
			<td><button type="reset" id="form-discard">Discard changes</button></td>
			<td><button type="submit" id="form-submit"><%-action.firstUpper() %></button></td>
		</tr>
	</table>
	<% if (values.id) { %>
	<input type="hidden" id="gid" name="gid" value="<%-values.id%>" />
	<% } %>
</form>
<a class="invisible" id="overlay-close" href="">Close</a>